@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2007, 2009, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2009-2012, 2014-2015 Free Software Foundation,
+   Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -49,18 +50,21 @@ static struct mu_conf_option mu_conf_option[] = {
 #ifdef WITH_BDB2
   { "WITH_BDB2", N_("Berkeley DB v. 2") },
 #endif
+#ifdef WITH_BDB
+  { "WITH_BDB", N_("Berkeley DB") },
+#endif
 #ifdef WITH_NDBM
   { "WITH_NDBM", },
 #endif
-#ifdef WITH_OLD_DBM
-  { "WITH_OLD_DBM", N_("Old DBM support") },
-#endif
 #ifdef WITH_GDBM
   { "WITH_GDBM", N_("GNU DBM") },
 #endif
 #ifdef WITH_TOKYOCABINET
   { "WITH_TOKYOCABINET", N_("Tokyo Cabinet DBM") },
 #endif
+#ifdef WITH_KYOTOCABINET
+  { "WITH_KYOTOCABINET", N_("Kyoto Cabinet DBM") },
+#endif
 #ifdef WITH_GNUTLS
   { "WITH_GNUTLS", N_("TLS support using GNU TLS") },
 #endif
