@@ -1,6 +1,5 @@
 /* cfg_driver.c -- Main driver for Mailutils configuration files
-   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
-   Inc.
+   Copyright (C) 2007-2012, 2014-2015 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -169,7 +168,7 @@ dup_container (struct mu_cfg_cont **pcont)
       newcont->v.section.offset = oldcont->v.section.offset;
       newcont->v.section.docstring = oldcont->v.section.docstring;
       newcont->v.section.children = NULL;
-      mu_list_do (oldcont->v.section.children, _dup_cont_action, &dd);
+      mu_list_foreach (oldcont->v.section.children, _dup_cont_action, &dd);
       break;
 
     case mu_cfg_cont_param:
@@ -329,7 +328,7 @@ mu_config_clone_container (struct mu_cfg_cont *cont)
   switch (cont->type)
     {
     case mu_cfg_cont_section:
-      mu_list_do (cont->v.section.children, _clone_action, NULL);
+      mu_list_foreach (cont->v.section.children, _clone_action, NULL);
       break;
 
     case mu_cfg_cont_param:
@@ -503,7 +502,7 @@ mu_parse_config (const char *file, const char *progname,
 		 void *target_ptr)
 {
   int rc;
-  char *full_name = mu_tilde_expansion (file, "/", NULL);
+  char *full_name = mu_tilde_expansion (file, MU_HIERARCHY_DELIMITER, NULL);
   if (full_name)
     {
       if (access (full_name, R_OK) == 0)
