@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2004, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999-2001, 2004, 2007, 2010-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -12,9 +13,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General
-   Public License along with this library; if not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA */
+   Public License along with this library.  If not, see
+   <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -69,7 +69,8 @@ mu_nntp_post (mu_nntp_t nntp, mu_stream_t stream)
 
     post_loop:
     case MU_NNTP_POST_0:
-      status = mu_stream_readline (stream, nntp->post.buf, nntp->post.len, nntp->post.offset, &(nntp->post.nread));
+      status = mu_stream_readline (stream, nntp->post.buf, nntp->post.len,
+				   &nntp->post.nread);
       MU_NNTP_CHECK_EAGAIN (nntp, status);
       nntp->post.offset += nntp->post.nread;
       if  (nntp->post.nread > 0)
