@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2007, 2009, 2010, 2011 Free Software Foundation,
-   Inc.
+   Copyright (C) 2003, 2007, 2009-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #ifdef WITH_TLS
 
 int
-pop3d_stls (char *arg)
+pop3d_stls (char *arg, struct pop3d_session *session)
 {
   if (strlen (arg) != 0)
     return ERR_BAD_ARGS;
@@ -30,6 +30,15 @@ pop3d_stls (char *arg)
   if (state != initial_state)
     return ERR_WRONG_STATE;
 
+  switch (session->tls)
+    {
+    case tls_ondemand:
+    case tls_required:
+      break;
+    default:
+      return ERR_WRONG_STATE;
+    }
+  
   if (tls_done)
     return ERR_TLS_ACTIVE;
 
@@ -46,7 +55,7 @@ pop3d_stls (char *arg)
     }
 
   state = AUTHORIZATION;  /* Confirm we're in this state. Necessary for
-			     --tls-required to work */
+			     "tls required" to work */
 
   return OK;
 }
